Name:		dpm-dsi
Summary:	Disk Pool Manager (DPM) plugin for the Globus GridFTP server
Version:	1.9.3
Release:	5%{?dist}
License:	ASL 2.0
Group:		Applications/Internet
URL:		https://svnweb.cern.ch/trac/lcgdm/wiki/Dpm
# The source of this package was pulled from upstream's vcs. Use the
# following commands to generate the tarball:
# svn export http://svn.cern.ch/guest/lcgdm/dpm-dsi/tags/dpm-dsi_1_9_3c dpm-dsi-1.9.3
# tar -czvf dpm-dsi-1.9.3.tar.gz dpm-dsi-1.9.3
Source0:	%{name}-%{version}.tar.gz
# https://its.cern.ch/jira/browse/LCGDM-1408
Patch0:   dpm-dsi-eof.patch
Patch1:   dpm-dsi-fts2_issue.patch 
Buildroot:	%{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)

BuildRequires:		cmake
BuildRequires:		dmlite-devel
BuildRequires:		globus-gridftp-server-devel
BuildRequires:		voms-devel

Requires(preun):	chkconfig
Requires(preun):	initscripts
Requires(post):		chkconfig
Requires(postun):	initscripts
Requires:		globus-gridftp-server-progs%{?_isa}
Requires:		dmlite-libs >= 0.6.2

Provides:		DPM-gridftp-server = %{version}-%{release} 
Obsoletes:		DPM-gridftp-server <= 1.8.1
Provides:		DPM-DSI = %{version}-%{release} 
Obsoletes:		DPM-DSI <= 1.8.1

%description
The dpm-dsi package provides a Disk Pool Manager (DPM) plugin for the 
Globus GridFTP server, following the Globus Data Storage Interface (DSI).

The Disk Pool Manager (DPM) is a lightweight storage solution for grid sites.
It offers a simple way to create a disk-based grid storage element and 
supports relevant protocols (SRM, gridFTP, RFIO) for file 
management and access.

Globus provides open source grid software, including a server implementation
of the GridFTP protocol. This plugin implements the DPM backend specifics 
required to expose the data using this protocol.

%prep
%setup -q -n %{name}-%{version}
%patch0 -p0
%patch1 -p0

%build
%cmake . -DCMAKE_INSTALL_PREFIX=/

make %{?_smp_mflags}

%install
rm -rf %{buildroot}
make DESTDIR=%{buildroot} install

install -p -d -m 755 %{buildroot}%{_localstatedir}/log/dpm-gsiftp

%clean
rm -rf %{buildroot}

%files
%defattr(-,root,root)
%{_initrddir}/dpm-gsiftp
%config(noreplace) %{_sysconfdir}/logrotate.d/dpm-gsiftp
%config(noreplace) %{_sysconfdir}/sysconfig/dpm-gsiftp
%{_libdir}/libglobus_gridftp_server_dmlite*.so*
%{_localstatedir}/log/dpm-gsiftp
%doc LICENSE RELEASE-NOTES

%post
/sbin/chkconfig --add dpm-gsiftp
/sbin/ldconfig

%preun
if [ $1 -eq 0 ] ; then
	/sbin/service dpm-dsi stop > /dev/null 2>&1
	/sbin/chkconfig --del dpm-gsiftp
fi

%postun
/sbin/ldconfig 
if [ $1 -ge 1 ]; then
	/sbin/service dpm-gsiftp condrestart > /dev/null 2>&1 || :
fi

%changelog
* Sat Aug 16 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.9.3-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.9.3-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Fri May 23 2014 Michal Simon <michal.simon@cern.ch> - 1.9.3-3
- Patch for the FTS2 issue 

* Thu May 15 2014 Alejandro Alvarez <aalvarez@cern.ch> - 1.9.3-2
- Patch for proper EOF handling

* Wed Mar 12 2014 Alejandro Alvarez <aalvarez@cern.ch> - 1.9.3-1
- Update for new upstream release
- Fixed bogus date

* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.9.0-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Mon May 06 2013 Alejandro Alvarez <aalvarez@cern.ch> - 1.9.0-3
- Removed devel package
- Removed %{?_isa} suffix from globus-gridftp-server-progs

* Wed Feb 13 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.9.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Wed Dec 19 2012 Ricardo Rocha <ricardo.rocha@cern.ch> - 1.9.0-1
- Update for new upstream release

* Fri Dec 14 2012 Ricardo Rocha <ricardo.rocha@cern.ch> - 1.8.3-1
- Update to new upstream release
- Removed previously required patches (integrated upstream)

* Wed Jul 18 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.8.2-8
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Fri Jan 13 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.8.2-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Mon Nov 28 2011 Dan Horák <dan[at]danny.cz> - 1.8.2-6
- fix build on 64-bit arches (s390x, sparc64 and possibly others)

* Tue Nov 15 2011 Ricardo Rocha <ricardo.rocha@cern.ch> - 1.8.2-5
- Removed architecture from globus-gridftp-server-progs requires

* Wed Nov 09 2011 Ricardo Rocha <ricardo.rocha@cern.ch> - 1.8.2-4
- Added patch for proper libdir usage in ppc64

* Wed Nov 09 2011 Ricardo Rocha <ricardo.rocha@cern.ch> - 1.8.2-3
- Added patch for LD_LIBRARY_PATH setting in init script

* Fri Nov 04 2011 Ricardo Rocha <ricardo.rocha@cern.ch> - 1.8.2-2
- Removed README and LICENSE from devel package
- Added parallel flags to make command

* Mon Oct 17 2011 Ricardo Rocha <ricardo.rocha@cern.ch> - 1.8.2-1
- Initial build
